searchData={"items":[{"type":"module","title":"PhoenixFormAwesomplete","doc":"PhoenixFormAwesomplete is a [Phoenix form helper](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html)\nthat utilizes Lea Verou's autocomplete / autosuggest / typeahead /\ninputsearch [Awesomplete widget](https://leaverou.github.io/awesomplete/index.html), \ncomplying to accessibility standards (Section 508, WCAG).\n\nIt comes with an AwesompleteUtil [javascript library](https://nico-amsterdam.github.io/awesomplete-util/index.html)\nwhich adds the following features:\n\n- Dynamic remote data loading; based on what is typed-in it performs an ajax lookup.\n- Allow HTML markup in the shown items. Show value with description. Optionally search in the description text.\n- Show when there is an exact match.\n- Show when there isn't a match.\n- When there is an exact match show related data (supplied in the remote data) in other parts of the page.\n- Select the highlighted item with the tab-key.\n\n[Online demo](https://nico-amsterdam.github.io/awesomplete-util/phoenix.html)","ref":"PhoenixFormAwesomplete.html"},{"type":"module","title":"Use cases - PhoenixFormAwesomplete","doc":"An autocomplete component is a free text input that provides suggestions while typing. It is not necessary to choose one of the suggestions, but of course a form validator can reject disallowed input.\n\nThe HTML combobox is very suitable for this. The combobox looks like a   but it doesn't limit the input. It consists of a   or   element combined with a   with   elements.\nThe options cannot contain HTML markup.\n\nWhen using LiveView the datalist of the HTML combobox can be made dynamic, with different suggestions based on the typed input. Like [this dictionary search demo](https://github.com/chrismccord/phoenix_live_view_example/blob/master/lib/demo_web/live/search_live.ex).\nHowever, when options are used with a text that differs from the value, the combobox will behave [different in different browsers](https://github.com/whatwg/html/issues/9986). \n\nWhen the standard combobox doesn't meet the requirements, a solution involving javascript can be used.\nFor LiveView there is for example this [Live Select](https://hex.pm/packages/live_select) component, but this component is not compliant with accessibility standards.\n\nThis Awesomplete component can be applied for any of these cases:\n- Use outside and inside LiveView. It is even possible to make a HEEx fragment with autocomplete that works in both. See the next chapter.\n- It is specially suitable for suggestions supplied by HTTP web services that produce JSON. Although the default is to use Ajax calls, it is [possible to use Phoenix channels](#module-faq). And, as long as the responses can be converted to Javascript arrays, it is also fine.\n- When accessibility is important; the widget has been tested for accessibility (Section 508, WCAG).\n- The list with suggestions can be customized, for example to show an extra description. Any HTML can be used in the suggestions.\n- It can give suggestions for an input field with multiple values.\n- It doesn't force the user to pick one of the suggestions; other values can be entered.\n- It can highlight the input field when there is a match (green) or when there isn't (red).\n- The client stops interacting with the backend, and filters on it's own when enough characters have been typed. This is when the suggestion list has become smaller than the search result limit. The client side filter is not affected by network latency, so it responds really quick.\n- Search requests with their responses can be cached by the browser, if the web service sets HTTP Cache headers.\n- A service worker can also be used for caching, if the standard ajax function is replaced with a function that uses the fetch api.\n- It can fill dependent readonly fields/tags. The typical example would be a productcode with a product description shown in order lines. For the existing order lines the database can join the product description to be shown on the screen, but for new entries and when changing the productcode it has te be dynamicly looked up. The description can be shown in the suggestion list, and when one suggestion is selected the description can be shown near the combobox.","ref":"PhoenixFormAwesomplete.html#module-use-cases"},{"type":"module","title":"Phoenix function components - PhoenixFormAwesomplete","doc":"In HEEx templates and ~H sigils, function components offer a method of reuse.\nAnd they make the HEEx markup arguable more readable.","ref":"PhoenixFormAwesomplete.html#module-phoenix-function-components"},{"type":"module","title":"Use both inside and outside LiveView - via hooks - PhoenixFormAwesomplete","doc":"The beauty of the client hooks is that this can be used both inside and outside LiveView as they both use the mounted callback. This makes it possible define a reusable component with autocomplete fields, which can be incorporated inside and outside LiveView.\n\nExample:\n\n```elixir\n<.simple_form\n  for={@form}\n  id=\"list-form\"\n  phx-target={@myself}\n  phx-change=\"validate\"\n  phx-submit=\"save\"\n>\n\n  <.input field={@form[:country]} type=\"autocomplete\" placeholder=\"Country\" phx-debounce=\"blur\" />\n\n  <.autocomplete forField={@form[:country]}\n                 url=\"https://restcountries.com/v2/all\"\n                 loadall=\"true\"\n                 prepop=\"true\"\n                 minChars=\"1\"\n                 maxItems=\"8\"\n                 value=\"name\"\n                 />\n\n</.simple_form>\n```\n\n#### Why are hooks used instead of dynamically generated scripts?\n\nFor security reasons, LiveView doesn't execute the javascript in dynamicly loaded script tags. Adding new javascript after the page is loaded via the HTTP-request is what every malicious Cross Site Scripting (XSS) code tries to do. Via the Content-Security-Policy HTTP-header, it is possible to prevent dynamicly loaded scripts to be executed.\nIn LiveView the javascript code is loaded as a static asset, and\n [client hooks via the phx-hook](https://hexdocs.pm/phoenix_live_view/js-interop.html#client-hooks-via-phx-hook) can be used to execute javascript code for\n dynamicly added DOM elements.\nInstead of generating javascript code for every autocomplete field, a javascript hook\nis used which gets it's parameters at runtime.","ref":"PhoenixFormAwesomplete.html#module-use-both-inside-and-outside-liveview-via-hooks"},{"type":"module","title":"Use outside LiveView, a.k.a. \"dead\" views - via page scripts - PhoenixFormAwesomplete","doc":"The advantage of embedded page scripts is that anonymous functions and\nfunctions defined on the same page can be used.\nIt also offers a smoother migration path from PhoenixFormAwesomplete version 0.1.\nThe EEx templates can be rewritten to use function components.\nThe input tag is separated from the script tag of Awesomplete,\nwhich makes it easier to customize the style of the input field.\n\nThe <.autocomplete> tag in the HEEX template will produce a script in the HTML page.\n\nExample:\n\n```elixir\n<.simple_form :let={f} for={@changeset} action={@action}>\n\n  <.input field={f[:country]} type=\"text\" label=\"Country\" />\n\n  <.autocomplete forField={f[:country]}\n                 url=\"https://restcountries.com/v2/all\"\n                 loadall=\"true\"\n                 prepop=\"true\"\n                 minChars=\"1\"\n                 maxItems=\"8\"\n                 value=\"name\"\n                 nonce={@script_src_nonce}\n                 />\n\n</.simple_form>\n```\n\nThe nonce in the example above, is to allow the inline script to be executed\nin combination with a Content-Security-Policy that doesn't\nallow unsafe evals or unsafe inline scripts.","ref":"PhoenixFormAwesomplete.html#module-use-outside-liveview-a-k-a-dead-views-via-page-scripts"},{"type":"module","title":"Security - PhoenixFormAwesomplete","doc":"","ref":"PhoenixFormAwesomplete.html#module-security"},{"type":"module","title":"Content-Security-Policy - PhoenixFormAwesomplete","doc":"As mentioned before, use a safe Content-Security-Policy (CSP):\n- do not allow unsafe eval\n- do not allow unsafe inline scripts\n- In the connect_src whitelist only the url's of trusted sites. Make sure that the url's of Awesomplete cannot be tampered with.","ref":"PhoenixFormAwesomplete.html#module-content-security-policy"},{"type":"module","title":"Trusted web services - PhoenixFormAwesomplete","doc":"Use only trusted web services. As a safety measure against cross-site scripting (XSS) it is possible to sanatize or escape HTML in the JSON responses via a convertResponse function.\n\nWhen an external web service is used directly, than this service will not only see the searched text but also the client IP address.\n\nMost web services can only be accessed with a session cookie or a valid token in the request header.\nUse a custom ajax function to set withCredential to true on the XMLHttpRequest object to send session cookies, or \nset the necessairy request headers when XHR is in opened state.","ref":"PhoenixFormAwesomplete.html#module-trusted-web-services"},{"type":"module","title":"Installation - PhoenixFormAwesomplete","doc":"","ref":"PhoenixFormAwesomplete.html#module-installation"},{"type":"module","title":"Installation for using both inside and outside LiveView - PhoenixFormAwesomplete","doc":"- Add `phoenix_form_awesomplete`to the list of dependencies in `mix.exs`:\n  ```elixir\n  def deps do\n    [\n    {:phoenix_form_awesomplete, \"~> 1.0\"}\n    ]\n  end\n  ```\n- Run\n  ```sh\n  mix deps.get\n  ```\n- Add the import statement in assets/js/app.js\n  ```javascript\n  import { AwesompleteUtil, attachAwesomplete, copyValueToId } from \"phoenix_form_awesomplete\"\n  ```\n- Add the Hooks Autocomplete and AutocompleteCopyValueToId in assets/js/app.js and pass the hooks to the LiveSocket\n  ```javascript\n\n  const AU = AwesompleteUtil\n      , customAwesompleteContext = {\n\n    // These functions and objects can be referenced by name in the autocomplete function components.\n    // This list can be customized.\n\n    filterContains:   AU.filterContains\n  , filterStartsWith: AU.filterStartsWith\n  , filterWords:      AU.filterWords\n  , filterOff:        AU.filterOff\n\n  , item:             AU.item          // does NOT mark matching text\n  // , itemContains:     AU.itemContains  // this is the default, no need to specify it.\n  , itemStartsWith:   AU.itemStartsWith\n  , itemMarkAll:      AU.itemMarkAll   // also mark matching text inside the description\n  , itemWords:        AU.itemWords     // mark matching words\n\n  , jsonFlatten:      AU.jsonFlatten   // Utility to flatten deep JSON structures\n\n    // add your custom functions and/or lists here\n\n  }\n\n  let Hooks = {}\n\n  Hooks.Autocomplete = {\n    mounted() { attachAwesomplete(this.el, customAwesompleteContext, {} /* defaultSettings */ ) }\n  }\n\n  Hooks.AutocompleteCopyValueToId = {\n    mounted() { copyValueToId(this.el) }\n  }\n\n  // modify the LiveSocket params to add the hooks\n  let liveSocket = new LiveSocket(\"/live\", Socket, {\n    longPollFallbackMs: 2500,\n    params: {_csrf_token: csrfToken},\n    hooks: Hooks\n  })\n  ```\n- Add these function components in lib/ _web/components/core_components.ex:\n  ```elixir\n  @awesomplete PhoenixFormAwesomplete.HookComponent\n\n  defdelegate autocomplete(assigns), to: @awesomplete\n  defdelegate copy_value_to_id(assigns), to: @awesomplete\n  defdelegate copy_value_to_field(assigns), to: @awesomplete\n  ```\n\n- Add a new input type called `autocomplete` in lib/ _web/components/core_components.ex:\n\n  The `core_components.ex` file may look different for every project, but here we assume there is a\n  function to handle `input` for `type=\"text\"`. Copy this function to handle the new `autocomplete` type\n  like in the example below. Pattern match the new type in the function argument.\n\n  Surrounding the `input` tag there must be a `span` or `div` tag with a unique id, and with the `phx‑update=\"ignore\"` attribute.\n  LiveView should not do DOM updates on the `input` tag that is manipulated by the Awesomplete widget.\n  The errors below the input field can and should be updated by LiveView.\n\n  ```elixir\n  def input(%{type: \"autocomplete\"} = assigns) do\n    assigns = assign(assigns, span_id: assigns.id <> \"-domspace\")\n    ~H\"\"\"\n     \n      <.label for={@id}><%= @label %></.label>\n       \n         \n       \n      <.error :for={msg <- @errors}><%= msg %></.error>\n     \n    \"\"\"\n  end\n  ```\n\n  and add the `autocomplete` in the allowed types:\n\n  ```elixir\n  attr :type, :string,\n    default: \"text\",\n    values: ~w(autocomplete checkbox color date datetime-local email file hidden month number password\n               range radio search select tel text textarea time url week)\n  ```\n\n- Add in assets/css/app.css\n  ```css\n  @import \"../../deps/phoenix_form_awesomplete/priv/static/awesomplete_bundle.css\";\n  ```\n  To modify this file, copy it to your assets/css directory and import that css file.\n- Run\n  ```sh\n  mix phx.server\n  ```","ref":"PhoenixFormAwesomplete.html#module-installation-for-using-both-inside-and-outside-liveview"},{"type":"module","title":"Installation for use outside LiveView only - PhoenixFormAwesomplete","doc":"- Add `phoenix_form_awesomplete`to the list of dependencies in `mix.exs`:\n  ```elixir\n  def deps do\n    [\n    {:phoenix_form_awesomplete, \"~> 1.0\"}\n    ]\n  end\n  ```\n- Run\n  ```sh\n  mix deps.get\n  ```\n- Add these function components in lib/ _web/components/core_components.ex:\n  ```elixir\n  @awesomplete PhoenixFormAwesomplete.EmbedScriptComponent\n\n  defdelegate autocomplete(assigns), to: @awesomplete\n  defdelegate copy_value_to_id(assigns), to: @awesomplete\n  defdelegate copy_value_to_field(assigns), to: @awesomplete\n  ```\n- Add this code in assets/js/app.js\n  ```javascript\n  import { Awesomplete, AwesompleteUtil } from \"phoenix_form_awesomplete\"\n  ```\n- In lib/ _web/components/layouts/root.html.heex remove 'defer' for app.js:\n  ```elixir\n    \n  ```\n  Awesomplete and AwesompleteUtil must be loaded before running the inline scripts.\n- Add in assets/css/app.css\n  ```elixir\n  @import \"../../deps/phoenix_form_awesomplete/priv/static/awesomplete_bundle.css\";\n  ```\n  To modify this file, copy it to your assets/css directory and import that css file.\n- Run\n  ```sh\n  mix phx.server\n  ```","ref":"PhoenixFormAwesomplete.html#module-installation-for-use-outside-liveview-only"},{"type":"module","title":"Accessibility - PhoenixFormAwesomplete","doc":"The Awesomplete widget is accessible (Section 508, WCAG).\nHowever, when using custom HTML in the suggestion list, this solution must be tested separately for compliance.\n\nThe red/green border color to indicate if there a match or not is not helpfull for people with red-green color blindness.\nThe 2 pixel border size might be not enough for people with a low vision.  And if they use a screen reader, the screen reader will paint it's own border around the focused element, hiding the red/green border color.","ref":"PhoenixFormAwesomplete.html#module-accessibility"},{"type":"module","title":"FAQ - PhoenixFormAwesomplete","doc":"","ref":"PhoenixFormAwesomplete.html#module-faq"},{"type":"module","title":"Is it possible to use Phoenix channels instead of ajax web service calls? - PhoenixFormAwesomplete","doc":"Yes, the ajax call can be replaced.\n\nAs `url` we will use the keyword `livesocket`.  Add this in `assets/js/app.js`\n```javascript\nfunction ajax2live(url, urlEnd, val, fn, xhr) {\n  if (url && url.startsWith('livesocket:')) {\n      const awe = this\n          , phxEvent = url.substr(url.indexOf(':') + 1)\n          , phxData = {'value':val, 'id':awe.input.id};\n      // secretly use this internal function to push events\n      liveSocket.execJSHookPush(awe.input, phxEvent, phxData, () => { console.log('sent ' + val); } );\n  }\n  else\n  {\n      AwesompleteUtil.ajax(url, urlEnd, val, fn, xhr);\n  }\n};\n```\n\nIn `assets/js/app.js` add in `customAwesompleteContext` the above function\n```javascript\n  , ajax2live:  ajax2live\n```\n\nIn `assets/js/app.js` add in the `mounted` function, add a function to handle server response\n```javascript\nconst awe = attachAwesomplete(this.el, customAwesompleteContext, {} /* defaultSettings */ );\nthis.handleEvent(`update-list-${awe.input.id}`,\n  ({queryResult, queryValue}) => { AwesompleteUtil.updateList(awe, queryResult, queryValue); }\n);\n```\n\nIn the HEEx template, in the .input add `phx-target` and in the .autocomplete refer to the new ajax function and change the url\n```elixir\n<.input field={@form[:country]} type=\"text\" placeholder=\"Country\" phx-target={@myself} phx-debounce=\"blur\" />\n\n<.autocomplete\n  forField={@form[:country]}\n  url=\"livesocket:update-country-list\"\n  minChars=\"1\"\n  maxItems=\"5\"\n  ajax=\"ajax2live\"\n  />\n```\n\nHandle the event in LiveView:\n```elixir\ndef handle_event(\"update-country-list\", %{\"value\" => val, \"id\" => id}, socket) do\n  newCountryList = ... your query logic here ...\n  {:noreply, push_event(socket, \"update-list-#{id}\", %{queryResult: newCountryList, queryValue: val})}\nend\n```","ref":"PhoenixFormAwesomplete.html#module-is-it-possible-to-use-phoenix-channels-instead-of-ajax-web-service-calls"},{"type":"module","title":"On mobile devices the suggestions are shown behind the virtual keyboard. Do you have a solution? - PhoenixFormAwesomplete","doc":"With a bit of javascript it is possible to scroll up the input field to the top of the screen when suggestions are shown on small devices.\n```javascript\nwindow.addEventListener('awesomplete-open', (el) => {\n  if (window.innerWidth < 577 && window.innerHeight < 800) el.target.scrollIntoView();\n});\n```\nPut this in [scroll.js](https://nico-amsterdam.github.io/awesomplete-util/js/scroll.js) and add this\njavascript file in the header of the page.\n\nAlso, set maxItems to a low value when it is used on a small device.","ref":"PhoenixFormAwesomplete.html#module-on-mobile-devices-the-suggestions-are-shown-behind-the-virtual-keyboard-do-you-have-a-solution"},{"type":"module","title":"Is it possible to group suggestions? - PhoenixFormAwesomplete","doc":"You can add the group in the description to show for each suggestion to which group it belongs,\nbut the Awesomplete widget has not the option to show suggestions in groups.\n\nAlternatives:\n- Split the input in two fields: one to select the group, and in the autocomplete field show only items of the selected group.\n- Use the HTML select element. It supports the optgroup tag.\n- This javascript component [kraaden autocomplete](https://github.com/kraaden/autocomplete#grouping-suggestions) has a grouping feature.","ref":"PhoenixFormAwesomplete.html#module-is-it-possible-to-group-suggestions"},{"type":"module","title":"PhoenixFormAwesomplete raw example - PhoenixFormAwesomplete","doc":"","ref":"PhoenixFormAwesomplete.html#module-phoenixformawesomplete-raw-example"},{"type":"module","title":"IEx - PhoenixFormAwesomplete","doc":"iex> {:safe, [input, script]} = PhoenixFormAwesomplete.awesomplete(:user, :drinks,\n    ...> [\"data-list\": \"beer, gin, soda, sprite, water, vodga, whine, whisky\"],\n    ...> %{ minChars: 1 } )\n    iex> to_string input\n    \" \n    \" id=\\\"user_drinks\\\" name=\\\"user[drinks]\\\" type=\\\"text\\\">\"\n    iex> script\n    \" AwesompleteUtil.start('#user_drinks', {}, {minChars: 1}); \"\n\nThe first three parameters are passed on unchanged to the Phoenix form [text_input](https://hexdocs.pm/phoenix_html/Phoenix.HTML.Form.html#text_input/3) which generates the input tag.\n`minChars` is an option for the Awesomplete object which is started with inline javascript.\nJust adding the `multiple` option changes the generated javascript code completely, the PhoenixFormAwesomplete module\ntakes care of that.\nInstead of an server side generated data-list it is possible to specify an url of a JSON web service and\nlet the client-code lookup the data list on-demand while typing.\nLook at the [live examples](https://nico-amsterdam.github.io/awesomplete-util/phoenix.html) with code.\n\n\nIt is possible to use aliases for the javascript library references in the generated page scripts\nvia the environment variables `util` and `awesomplete`.\nThe default names, `AwesompleteUtil` and `Awesomplete` respectively, are a bit long.\nThis can shorten the average page size.\nFor example use this javascript:\n     var AU = AwesompleteUtil, AW = Awesomplete;\nand change the variables via the application config:\n     :phoenix_form_awesomplete, util:         \"AU\"\n     :phoenix_form_awesomplete, awesomplete:  \"AW\"\nAfter changing the config/config.exs run:\n     mix deps.compile --force phoenix_form_awesomplete","ref":"PhoenixFormAwesomplete.html#module-iex"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete/4","doc":"This method generates an input tag and inline javascript code that starts Awesomplete. Use this in (L)EEx templates. For HEEx templates it recommended to use <.input in combination with awesomplete_script/2.\n\nAwesomplete options:\n * `ajax`            - Replace ajax function. Supplied function receives these parameters: (url, urlEnd, val, fn, xhr). fn is the callback function. Default: AwesompleteUtil.ajax.\n * `assign`          - Assign the Awesomplete object to a variable. true/false/name. If true the variable name will be 'awe\\_' + id of input tag. Default: false\n * `autoFirst`       - true/false. Automatically select the first element. Default: false.\n * `combobox`        - Id of the combobox button. true/false/id. If true the assumed button id is 'awe\\_btn\\_' + id of the input tag. Default: false\n * `container`       - Container function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility). By default a div element is added as the parent of the input element.\n * `convertInput`    - Convert input function which receives the input text as parameter. This function is used normalize the input text. Internally convert the input text for search calls and for comparison with the suggestions. By default it trims the input and converts it to lowercase for a case-insensitive comparison. It is applied to both the input text and the suggestion text before comparing. In advanced cases like the multiple values, the convertInput is used to extract the search text.\n * `convertResponse` - Convert JSON response from ajax calls. This function is called with the parsed JSON, and allows conversion of the data before further processing. Default: nil - no conversion.\n * `data`            - Data function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility)\n * `debounce`        - Time in milliseconds to wait for additional user input before doing the ajax call to retrieve suggestions. It limits the rate at which the json service is called per user session.\n * `descr`           - Name of the field in the data list (the JSON response) that contains the description text to show below the value in the suggestion list. Default: no description\n * `descrSearch`     - true/false. Filter must also search the input value in the description field. Default: false\n * `filter`          - Filter function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility). Mostly use Awesomplete.FILTER\\_STARTSWITH or Awesomplete.FILTER\\_CONTAINS. If label is different as value, filter on value with AweompleteUtil.filterStartsWith, AwesompleteUtil.filterContains or AwesompleteUtil.filterWords. To turn off filtering, use AwesompleteUtil.filterOff.\n * `item`            - Item function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility) with parameters text, input and itemId. Default is to highlight all occurrences of the input text. Use AwesompleteUtil.itemStartsWith or AwesompleteUtil.itemWords if that matches with the used filter.\n * `label`           - Name of the field in the data list (the JSON response) that contains the text that should be shown instead of the value.\n * `list`            - Data list as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility).\n * `listLabel`       - Denotes a label to be used as aria-label on the generated autocomplete list.\n * `loadall`         - true/false. Use true if the data list contains all items, and the input value should not be used in ajax calls. Default: false\n * `limit`           - number. If a limit is specified, and the number of items returned by the server is equal or more as this limit, the AwesompleteUtil code assumes that there are more results, so it will re-query if more characters are typed to get more refined results. The limit:1 tells that not more than 1 result is expected, so the json service doesn’t have to return an array. With limit:0 it will always re-query if more characters are typed and the result doesn't have to be an array either. Limit:-1 will always requery and the expected result is an array. When no limit is specified, the code assumes that all possible suggestions are returned based on the typed characters, and it will not re-query if more characters are typed. It uses the specified filter for the suggestions in the dropdown. Default: no limit\n * `maxItems`        - Maximum number of suggestions to display. Default: 10\n * `minChars`        - Minimum characters the user has to type before the autocomplete popup shows up. Default: 2\n * `multiple`        - true/false/characters. Separators to allow multiple values. If true, the separator will be the space character. Default: false\n * `nonce`           - Content-Security-Policy nonce attribute for the script tag. Default: no nonce. If specified it must contain a non-empty value.\n * `prepop`          - true/false. If true do lookup initial/autofilled value and send awesomplete-prepop event. Default: false\n * `replace`         - Replace function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility). The replace function will be called for suggestions, to determine whether the input text matches a suggestion after replacement.\n * `sort`            - Sort function as defined in [Awesomplete](http://leaverou.github.io/awesomplete/index.html#extensibility)\n * `statusNoResults` - Screen reader text to replace the default: 'No results found'\n * `statusTypeXChar` - Screen reader text to replace the default: 'Type {0} or more characters for results'. The placeholder {0} will be replaced with the minimum number of characters (minChars).\n * `statusXResults`  - Screen reader text to replace the default: '{0} results found'. The placeholder {0} will be replaced with the number of results.\n * `url`             - url for ajax calls.\n * `urlEnd`          - Addition at the end of the url for the ajax call, after the input value. Or a function, which receives the value and must return the last part of the url.\n * `value`           - Name of the field in the data list (the JSON response) that contains the value.","ref":"PhoenixFormAwesomplete.html#awesomplete/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete/4","doc":"iex> {:safe, [inp, scr]} = PhoenixFormAwesomplete.awesomplete(:user, :eyes,\n    ...> [\"data-list\": \"blue, brown, green\"],\n    ...>  %{ minChars: 1, multiple: \",;\", nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\" } )\n    iex> to_string inp\n    \" \"\n    iex> scr\n    \" AwesompleteUtil.start('#user_eyes', \" <>\n    \"{convertInput: function(input) {\" <>\n    \" return input.replace(/[,;]\\\\s*$/, '').match(/[^,;]*$/)[0].trim().toLowerCase(); }}, \" <>\n    \"{minChars: 1, \" <>\n    \"replace: function(data) {\" <>\n    \" var text=data.value;\" <>\n    \" this.input.value = this.input.value.match(/^.+[,;]\\\\s*|/)[0] + text + ', '; }, \" <>\n    \"filter: function(data, input) {\" <>\n    \" return Awesomplete.FILTER_CONTAINS(data, input.match(/[^,;]*([,;]\\\\s*)?$/)[0]); }, \" <>\n    \"item: function(text, input) {\" <>\n    \" return AwesompleteUtil.itemContains(text, input.match(/[^,;]*([,;]\\\\s*)?$/)[0]); }});\" <>\n    \" \"","ref":"PhoenixFormAwesomplete.html#awesomplete/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete_js/2","doc":"This method generates javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.html#awesomplete_js/2"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete_js/2","doc":"iex> ff = %Phoenix.HTML.FormField{form: \"user\", field: \"hobby\", id: \"user_hobby\", name: \"user[hobby]\", errors: [], value: nil}\n    iex> PhoenixFormAwesomplete.awesomplete_js(ff , %{ minChars: 1 } )\n    \"AwesompleteUtil.start('#user_hobby', {}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.html#awesomplete_js/2-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete_js/3","doc":"This method generates javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.html#awesomplete_js/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete_js/3","doc":"iex> PhoenixFormAwesomplete.awesomplete_js(:user, :hobby, %{ minChars: 1 } )\n    \"AwesompleteUtil.start('#user_hobby', {}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.html#awesomplete_js/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete_script/2","doc":"This method generates a script tag with javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.html#awesomplete_script/2"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete_script/2","doc":"iex> ff = %Phoenix.HTML.FormField{form: \"user\", field: \"hobby\", id: \"user_hobby\", name: \"user[hobby]\", errors: [], value: nil}\n    iex> PhoenixFormAwesomplete.awesomplete_script(ff, %{ minChars: 1 } )\n    {:safe,\n     \" AwesompleteUtil.start('#user_hobby', {}, {minChars: 1}); \"}\n\n    iex> PhoenixFormAwesomplete.awesomplete_script(:user, :hobby, %{ minChars: 1, nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\" } )\n    {:safe,\n     \" AwesompleteUtil.start('#user_hobby', {}, {minChars: 1}); \"}","ref":"PhoenixFormAwesomplete.html#awesomplete_script/2-example"},{"type":"function","title":"PhoenixFormAwesomplete.awesomplete_script/3","doc":"This method generates a script tag with javascript code for using Awesomplete(Util).\nAs awesomplete_script/2 but with form and field parameters as used in Phoenix.HTML.Form functions\ninstead of the Phoenix.HTML.FormField.\nThe form parameter is either a Phoenix.HTML.Form struct or an atom.","ref":"PhoenixFormAwesomplete.html#awesomplete_script/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.awesomplete_script/3","doc":"iex> PhoenixFormAwesomplete.awesomplete_script(:user, :hobby, %{ minChars: 1 } )\n    {:safe,\n     \" AwesompleteUtil.start('#user_hobby', {}, {minChars: 1}); \"}\n\n    iex> PhoenixFormAwesomplete.awesomplete_script(:user, :hobby, %{ minChars: 1, nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\" } )\n    {:safe,\n     \" AwesompleteUtil.start('#user_hobby', {}, {minChars: 1}); \"}","ref":"PhoenixFormAwesomplete.html#awesomplete_script/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_field/5","doc":"As copy_value_to_field/3 but with form and field parameters as used in Phoenix.HTML.Form functions\ninstead of the Phoenix.HTML.FormField's.\nThe source_form and target_form parameters are either a Phoenix.HTML.Form struct or an atom.","ref":"PhoenixFormAwesomplete.html#copy_to_field/5"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_field/5","doc":"iex> PhoenixFormAwesomplete.copy_to_field(:user, :color, \"label\", :door, :paint)\n    {:safe,\n     \" AwesompleteUtil.startCopy('#user_color', 'label', '#door_paint'); \"}","ref":"PhoenixFormAwesomplete.html#copy_to_field/5-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_field_script/6","doc":"Same as copy_to_field/5 but with an additional last argument for the script attributes.","ref":"PhoenixFormAwesomplete.html#copy_to_field_script/6"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_field_script/6","doc":"iex> PhoenixFormAwesomplete.copy_to_field_script(:user, :color, \"label\", :door, :paint, [nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"])\n    {:safe,\n     \" AwesompleteUtil.startCopy('#user_color', 'label', '#door_paint'); \"}","ref":"PhoenixFormAwesomplete.html#copy_to_field_script/6-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_id/4","doc":"As copy_value_to_id/3 but with form and field parameters as used in Phoenix.HTML.Form functions\ninstead of the Phoenix.HTML.FormField.\nThe source_form parameter is either a Phoenix.HTML.Form struct or an atom.","ref":"PhoenixFormAwesomplete.html#copy_to_id/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_id/4","doc":"iex> PhoenixFormAwesomplete.copy_to_id(:user, :color, \"label\", \"#awe-color-result\")\n    {:safe,\n     \" AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result'); \"}","ref":"PhoenixFormAwesomplete.html#copy_to_id/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_id_js/4","doc":"As copy_value_to_id_js/3 but with form and field parameters as used in Phoenix.HTML.Form functions\ninstead of the Phoenix.HTML.FormField.\nThe source_form and target_form parameters are either a Phoenix.HTML.Form struct or an atom.","ref":"PhoenixFormAwesomplete.html#copy_to_id_js/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_id_js/4","doc":"iex> PhoenixFormAwesomplete.copy_to_id_js(:user, :color, \"label\", \"#awe-color-result\")\n    \"AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result');\"","ref":"PhoenixFormAwesomplete.html#copy_to_id_js/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_to_id_script/5","doc":"Same as copy_to_id/4 but with an additional last argument for the script attributes.","ref":"PhoenixFormAwesomplete.html#copy_to_id_script/5"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_to_id_script/5","doc":"iex> PhoenixFormAwesomplete.copy_to_id_script(:user, :color, \"label\", \"#awe-color-result\", [nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"])\n    {:safe,\n     \" AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result'); \"}","ref":"PhoenixFormAwesomplete.html#copy_to_id_script/5-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_value_to_field/3","doc":"Create script tag with javascript that listens to `awesomplete-prepop` and `awesomplete-match` events on the source form field,\nand copies the `data_field` to the target form field.","ref":"PhoenixFormAwesomplete.html#copy_value_to_field/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_value_to_field/3","doc":"iex> ff_source = %Phoenix.HTML.FormField{form: \"palet\", field: \"color\", id: \"palet_color\", name: \"palet[color]\", errors: [], value: nil}\n    iex> ff_target = %Phoenix.HTML.FormField{form: \"palet\", field: \"paint\", id: \"palet_paint\", name: \"palet[paint]\", errors: [], value: nil}\n    iex> PhoenixFormAwesomplete.copy_value_to_field(ff_source, \"label\", ff_target)\n    {:safe,\n     \" AwesompleteUtil.startCopy('#palet_color', 'label', '#palet_paint'); \"}","ref":"PhoenixFormAwesomplete.html#copy_value_to_field/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_value_to_field_script/4","doc":"Same as copy_value_to_field/3 but with an additional last argument for the script attributes.","ref":"PhoenixFormAwesomplete.html#copy_value_to_field_script/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_value_to_field_script/4","doc":"iex> ff_source = %Phoenix.HTML.FormField{form: \"palet\", field: \"color\", id: \"palet_color\", name: \"palet[color]\", errors: [], value: nil}\n    iex> ff_target = %Phoenix.HTML.FormField{form: \"palet\", field: \"paint\", id: \"palet_paint\", name: \"palet[paint]\", errors: [], value: nil}\n    iex> PhoenixFormAwesomplete.copy_value_to_field_script(ff_source, \"label\", ff_target, [nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"])\n    {:safe,\n     \" AwesompleteUtil.startCopy('#palet_color', 'label', '#palet_paint'); \"}","ref":"PhoenixFormAwesomplete.html#copy_value_to_field_script/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_value_to_id/3","doc":"Create script tag with javascript that listens to `awesomplete-prepop` and `awesomplete-match` events,\nand copies the `data_field` to the DOM element with the given target id.\nThe `target id` is passed to the DOM document querySelector, and is typically\nset as a hash character with an element id.\nThe `target_id` can also be a javascript function.","ref":"PhoenixFormAwesomplete.html#copy_value_to_id/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_value_to_id/3","doc":"iex> ff = %Phoenix.HTML.FormField{form: \"palet\", field: \"color\", id: \"palet_color\", name: \"palet[color]\", errors: [], value: nil}\n    iex> PhoenixFormAwesomplete.copy_value_to_id(ff, \"label\", \"#awe-color-result\")\n    {:safe,\n     \" AwesompleteUtil.startCopy('#palet_color', 'label', '#awe-color-result'); \"}","ref":"PhoenixFormAwesomplete.html#copy_value_to_id/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_value_to_id_js/3","doc":"Create javascript that listens to `awesomplete-prepop` and `awesomplete-match` events,\nand copies the `data_field` to the DOM element with the given target id.\nThe `target id` is passed to the DOM document querySelector, and is typically\nset as a hash character with an element id.\nThe `target_id` can also be a javascript function.","ref":"PhoenixFormAwesomplete.html#copy_value_to_id_js/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_value_to_id_js/3","doc":"iex> ff = %Phoenix.HTML.FormField{form: \"palet\", field: \"color\", id: \"palet_color\", name: \"palet[color]\", errors: [], value: nil}\n    iex> PhoenixFormAwesomplete.copy_value_to_id_js(ff, \"label\", \"#awe-color-result\")\n    \"AwesompleteUtil.startCopy('#palet_color', 'label', '#awe-color-result');\"","ref":"PhoenixFormAwesomplete.html#copy_value_to_id_js/3-example"},{"type":"function","title":"PhoenixFormAwesomplete.copy_value_to_id_script/4","doc":"Same as copy_value_to_id/4 but with an additional last argument for script attributes.","ref":"PhoenixFormAwesomplete.html#copy_value_to_id_script/4"},{"type":"function","title":"Example - PhoenixFormAwesomplete.copy_value_to_id_script/4","doc":"iex> ff = %Phoenix.HTML.FormField{form: \"palet\", field: \"color\", id: \"palet_color\", name: \"palet[color]\", errors: [], value: nil}\n    iex> PhoenixFormAwesomplete.copy_value_to_id_script(ff, \"label\", \"#awe-color-result\", [nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"])\n    {:safe,\n     \" AwesompleteUtil.startCopy('#palet_color', 'label', '#awe-color-result'); \"}","ref":"PhoenixFormAwesomplete.html#copy_value_to_id_script/4-example"},{"type":"function","title":"PhoenixFormAwesomplete.script/1","doc":"Create script tag with the supplied script. No defer or async because this is used for inline script.","ref":"PhoenixFormAwesomplete.html#script/1"},{"type":"function","title":"Example - PhoenixFormAwesomplete.script/1","doc":"iex> PhoenixFormAwesomplete.script(\"alert(1);\")\n    {:safe, \" alert(1); \"}","ref":"PhoenixFormAwesomplete.html#script/1-example"},{"type":"function","title":"PhoenixFormAwesomplete.script/2","doc":"Same as script/1 with a second argument for the script attributes.","ref":"PhoenixFormAwesomplete.html#script/2"},{"type":"function","title":"Example - PhoenixFormAwesomplete.script/2","doc":"iex> PhoenixFormAwesomplete.script(\"alert(1);\" , [nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"])\n    {:safe, \" alert(1); \"}\n\n    iex> PhoenixFormAwesomplete.script(\"alert(2);\" , %{nonce: \"KG2FJFSN4LaCNyVRwTxRJjCB94Bdc41S\"})\n    {:safe, \" alert(2); \"}\n\n    iex> PhoenixFormAwesomplete.script(\"alert(3);\" , %{type: \"module\", id: \"x42\"})\n    {:safe, \" alert(3); \"}","ref":"PhoenixFormAwesomplete.html#script/2-example"},{"type":"module","title":"PhoenixFormAwesomplete.EmbedScriptComponent","doc":"Provides function components for the Awesomplete script generator component,\nto embed autocomplete functionality in the HTML pages.\nCan only be used outside LiveView.","ref":"PhoenixFormAwesomplete.EmbedScriptComponent.html"},{"type":"function","title":"PhoenixFormAwesomplete.EmbedScriptComponent.autocomplete/1","doc":"Wrapper for PhoenixFormAwesomplete.awesomplete_script.","ref":"PhoenixFormAwesomplete.EmbedScriptComponent.html#autocomplete/1"},{"type":"function","title":"Attributes - PhoenixFormAwesomplete.EmbedScriptComponent.autocomplete/1","doc":"* `forField` (`:any`) (required) - Phoenix.HTML.FormField struct or field name.\n* `forForm` (`:any`) - Phoenix.HTML.Form struct or form name. Not needed when FormField is used. Defaults to `nil`.\n* Global attributes are accepted. the options for awesomplete_script. Supports all globals plus: `[\"ajax\", \"assign\", \"autoFirst\", \"combobox\", \"container\", \"convertInput\", \"convertResponse\", \"data\", \"debounce\", \"descr\", \"descrSearch\", \"filter\", \"id\", \"item\", \"label\", \"list\", \"listLabel\", \"loadall\", \"limit\", \"maxItems\", \"minChars\", \"multiple\", \"prepop\", \"replace\", \"sort\", \"statusNoResults\", \"statusTypeXChar\", \"statusXResults\", \"type\", \"url\", \"urlEnd\", \"value\"]`.","ref":"PhoenixFormAwesomplete.EmbedScriptComponent.html#autocomplete/1-attributes"},{"type":"function","title":"PhoenixFormAwesomplete.EmbedScriptComponent.copy_value_to_field/1","doc":"Wrapper for PhoenixFormAwesomplete.copy_value_to_field.","ref":"PhoenixFormAwesomplete.EmbedScriptComponent.html#copy_value_to_field/1"},{"type":"function","title":"Attributes - PhoenixFormAwesomplete.EmbedScriptComponent.copy_value_to_field/1","doc":"* `sourceField` (`Phoenix.HTML.FormField`) (required) - a Phoenix.HTML.FormField struct retrieved from the form, for example: @f[:country].\n* `targetField` (`Phoenix.HTML.FormField`) (required) - a Phoenix.HTML.FormField struct retrieved from the form, for example: @f[:capital].\n* `dataField` (`:string`) - Optional, dataField to be copied, for example: capital. Defaults to `nil`.\n* Global attributes are accepted. script attributes.","ref":"PhoenixFormAwesomplete.EmbedScriptComponent.html#copy_value_to_field/1-attributes"},{"type":"function","title":"PhoenixFormAwesomplete.EmbedScriptComponent.copy_value_to_id/1","doc":"Wrapper for PhoenixFormAwesomplete.copy_value_to_id.","ref":"PhoenixFormAwesomplete.EmbedScriptComponent.html#copy_value_to_id/1"},{"type":"function","title":"Attributes - PhoenixFormAwesomplete.EmbedScriptComponent.copy_value_to_id/1","doc":"* `field` (`:any`) (required) - Phoenix.HTML.FormField struct or field name.\n* `form` (`:any`) - Phoenix.HTML.Form struct or form name. Not needed when FormField is used. Defaults to `nil`.\n* `dataField` (`:string`) - Optional, dataField to be copied, for example: capital. Defaults to `nil`.\n* `target` (`:string`) - css selector, for example: #capital.\n* Global attributes are accepted. script attributes.","ref":"PhoenixFormAwesomplete.EmbedScriptComponent.html#copy_value_to_id/1-attributes"},{"type":"module","title":"PhoenixFormAwesomplete.GenJS","doc":"Generate the javascript code for PhoenixFormAwesomplete.","ref":"PhoenixFormAwesomplete.GenJS.html"},{"type":"module","title":"Example - PhoenixFormAwesomplete.GenJS","doc":"iex> PhoenixFormAwesomplete.GenJS.awesomplete_js(\"user_drinks\", %{ minChars: 1, prepop: true } )\n    \"AwesompleteUtil.start('#user_drinks', {prepop: true}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.GenJS.html#module-example"},{"type":"function","title":"PhoenixFormAwesomplete.GenJS.awesomplete_js/2","doc":"This method generates javascript code for using Awesomplete(Util).","ref":"PhoenixFormAwesomplete.GenJS.html#awesomplete_js/2"},{"type":"function","title":"Example - PhoenixFormAwesomplete.GenJS.awesomplete_js/2","doc":"iex> PhoenixFormAwesomplete.GenJS.awesomplete_js(\"user_hobby\", %{ minChars: 1 } ) \n    \"AwesompleteUtil.start('#user_hobby', {}, {minChars: 1});\"","ref":"PhoenixFormAwesomplete.GenJS.html#awesomplete_js/2-example"},{"type":"function","title":"PhoenixFormAwesomplete.GenJS.copy_to_id_js/3","doc":"Create javascript that listens to `awesomplete-prepop` and `awesomplete-match` events,\nand copies the `data_field` to the DOM element with the given target id.\nThe `target_id` can also be a javascript function.","ref":"PhoenixFormAwesomplete.GenJS.html#copy_to_id_js/3"},{"type":"function","title":"Example - PhoenixFormAwesomplete.GenJS.copy_to_id_js/3","doc":"iex> PhoenixFormAwesomplete.GenJS.copy_to_id_js(\"#user_color\", \"label\", \"#awe-color-result\") \n    \"AwesompleteUtil.startCopy('#user_color', 'label', '#awe-color-result');\"","ref":"PhoenixFormAwesomplete.GenJS.html#copy_to_id_js/3-example"},{"type":"module","title":"PhoenixFormAwesomplete.HookComponent","doc":"Provides function components for the Awesomplete component,\nfor autocomplete functionality.\nUses a hook for the javascript code.\nUsable inside and outside LiveView.","ref":"PhoenixFormAwesomplete.HookComponent.html"},{"type":"function","title":"PhoenixFormAwesomplete.HookComponent.autocomplete/1","doc":"Provide functionality like PhoenixFormAwesomplete.awesomplete_script via client hook.","ref":"PhoenixFormAwesomplete.HookComponent.html#autocomplete/1"},{"type":"function","title":"Attributes - PhoenixFormAwesomplete.HookComponent.autocomplete/1","doc":"* `id` (`:string`)\n* `forField` (`:any`) (required) - Phoenix.HTML.FormField struct or field name.\n* `forForm` (`:any`) - Phoenix.HTML.Form struct or form name. Not needed when FormField is used.\n* `nonce` (`:any`) - In liveview the nonce will be ignored.\n* Global attributes are accepted. the options for awesomplete_script. Supports all globals plus: `[\"ajax\", \"assign\", \"autoFirst\", \"combobox\", \"container\", \"convertInput\", \"convertResponse\", \"data\", \"debounce\", \"descr\", \"descrSearch\", \"filter\", \"item\", \"label\", \"list\", \"listLabel\", \"loadall\", \"limit\", \"maxItems\", \"minChars\", \"multiple\", \"prepop\", \"replace\", \"sort\", \"statusNoResults\", \"statusTypeXChar\", \"statusXResults\", \"url\", \"urlEnd\", \"value\"]`.","ref":"PhoenixFormAwesomplete.HookComponent.html#autocomplete/1-attributes"},{"type":"function","title":"PhoenixFormAwesomplete.HookComponent.copy_value_to_field/1","doc":"Provide functionality like PhoenixFormAwesomplete.copy_value_to_field via client hook.","ref":"PhoenixFormAwesomplete.HookComponent.html#copy_value_to_field/1"},{"type":"function","title":"Attributes - PhoenixFormAwesomplete.HookComponent.copy_value_to_field/1","doc":"* `id` (`:string`)\n* `sourceField` (`:any`) (required) - Phoenix.HTML.FormField struct.\n* `targetField` (`:any`) (required) - Phoenix.HTML.FormField struct.\n* `nonce` (`:any`) - In liveview the nonce will be ignored.\n* Global attributes are accepted. dataField: Optional, dataField to be copied, for example: capital. Supports all globals plus: `[\"dataField\"]`.","ref":"PhoenixFormAwesomplete.HookComponent.html#copy_value_to_field/1-attributes"},{"type":"function","title":"PhoenixFormAwesomplete.HookComponent.copy_value_to_id/1","doc":"Provide functionality like PhoenixFormAwesomplete.copy_value_to_id via client hook.","ref":"PhoenixFormAwesomplete.HookComponent.html#copy_value_to_id/1"},{"type":"function","title":"Attributes - PhoenixFormAwesomplete.HookComponent.copy_value_to_id/1","doc":"* `id` (`:string`)\n* `field` (`:any`) (required) - Phoenix.HTML.FormField struct or field name.\n* `form` (`:any`) - Phoenix.HTML.Form struct or form name. Not needed when FormField is used.\n* `target` (`:any`) (required) - target: css selector, for example: #capital.\n* `nonce` (`:any`) - In liveview the nonce will be ignored.\n* Global attributes are accepted. dataField: Optional, dataField to be copied, for example: capital. Supports all globals plus: `[\"dataField\"]`.","ref":"PhoenixFormAwesomplete.HookComponent.html#copy_value_to_id/1-attributes"},{"type":"function","title":"PhoenixFormAwesomplete.HookComponent.release_dom/1","doc":"Transfer ownership of the DOM from LiveView to custom javascript code after the initial rendering.\nAnother way to set phx-update=\"ignore\" without scattering this phx attribute in the templates.","ref":"PhoenixFormAwesomplete.HookComponent.html#release_dom/1"},{"type":"function","title":"Attributes - PhoenixFormAwesomplete.HookComponent.release_dom/1","doc":"* `id` (`:string`) (required)\n* Global attributes are accepted.","ref":"PhoenixFormAwesomplete.HookComponent.html#release_dom/1-attributes"},{"type":"function","title":"Slots - PhoenixFormAwesomplete.HookComponent.release_dom/1","doc":"* `inner_block`","ref":"PhoenixFormAwesomplete.HookComponent.html#release_dom/1-slots"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}